@@ -363,7 +363,7 @@ open_plugin_so (const char *name)
     free_filename = 1;
   }
 
-  dl = dlopen (filename, RTLD_NOW|RTLD_LOCAL);
+  dl = dlopen (filename, RTLD_NOW|RTLD_GLOBAL);
   if (dl == NULL) {
     fprintf (stderr, "%s: %s: %s\n", program_name, filename, dlerror ());
     exit (EXIT_FAILURE);
@@ -373,7 +373,7 @@ open_plugin_so (const char *name)
   dlerror ();
   *(void **) (&plugin_init) = dlsym (dl, "plugin_init");
   if ((error = dlerror ()) != NULL) {
-    fprintf (stderr, "%s: %s: %s\n", program_name, name, dlerror ());
+    fprintf (stderr, "%s: %s: %s\n", program_name, name, error);
     exit (EXIT_FAILURE);
   }
   if (!plugin_init) {
